==> jc-1.4.0.tar.gz: soot/baf/toolkits/base/ExamplePeephole.c <==
// public class soot.baf.toolkits.base.ExamplePeephole

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class be56ff673eefd9d2 java_util_Iterator
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 2869754f09a70a54 soot_PatchingChain
// @dep_class 771084b7dcf26138 soot_Unit
// @dep_class c3ac678fa21bb70d soot_baf_InstanceCastInst
// @dep_class deba9086a8880c47 soot_baf_toolkits_base_ExamplePeephole
// @dep_class 6759975ef41a30c9 soot_baf_toolkits_base_Peephole

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Iterator
// @dep_header soot_Body
// @dep_header soot_PatchingChain
// @dep_header soot_Unit
// @dep_header soot_baf_InstanceCastInst
// @dep_header soot_baf_toolkits_base_ExamplePeephole
// @dep_header soot_baf_toolkits_base_Peephole

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Iterator.h"
#include "soot/Body.h"
#include "soot/PatchingChain.h"
#include "soot/Unit.h"
#include "soot/baf/InstanceCastInst.h"
#include "soot/baf/toolkits/base/ExamplePeephole.h"
#include "soot/baf/toolkits/base/Peephole.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_baf_toolkits_base_ExamplePeephole$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_baf_toolkits_base_ExamplePeephole$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_baf_toolkits_base_ExamplePeephole$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_baf_toolkits_base_ExamplePeephole$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_baf_toolkits_base_ExamplePeephole$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_baf_toolkits_base_ExamplePeephole$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_baf_toolkits_base_ExamplePeephole$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_baf_toolkits_base_ExamplePeephole, _init$52f4ad9f2989aeee);

void
_jc_soot_baf_toolkits_base_ExamplePeephole$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_baf_toolkits_base_ExamplePeephole$object *this)
{
	struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(40);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public boolean apply(soot.Body)
//

static _jc_linenum _jc_soot_baf_toolkits_base_ExamplePeephole$linenum_table$apply$26c2d07493ac3443[];

static const unsigned char _jc_soot_baf_toolkits_base_ExamplePeephole$param_ptypes$apply$26c2d07493ac3443[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$param_types$apply$26c2d07493ac3443[] = {
	&_jc_soot_Body$type
};

_jc_method _jc_soot_baf_toolkits_base_ExamplePeephole$method_info$apply$26c2d07493ac3443 = {
	.name=			"apply",
	.signature=		"(Lsoot/Body;)Z",
	.class=			&_jc_soot_baf_toolkits_base_ExamplePeephole$type,
	.param_types=		&_jc_soot_baf_toolkits_base_ExamplePeephole$param_types$apply$26c2d07493ac3443,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_baf_toolkits_base_ExamplePeephole$param_ptypes$apply$26c2d07493ac3443,
	.signature_hash=	_JC_JLONG(0x26c2d07493ac3443),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtable, soot_baf_toolkits_base_ExamplePeephole.apply$26c2d07493ac3443) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	8,
	      .table=	_jc_soot_baf_toolkits_base_ExamplePeephole$linenum_table$apply$26c2d07493ac3443
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_baf_toolkits_base_ExamplePeephole, apply$26c2d07493ac3443);

jboolean
_jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443(_jc_env *const env, _jc_soot_baf_toolkits_base_ExamplePeephole$object *this, _jc_soot_Body$object *param0)
{
	struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *r0;
	struct _jc_soot_Body$object *r1;
	struct _jc_object *r2;
	struct _jc_object *r3;
	struct _jc_soot_PatchingChain$object *r4;
	struct _jc_java_lang_Object$object *r5;
	jboolean z0;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(44);				// 0
	z0 = 0;
	_JC_LINE_NUMBER(46);				// 1
	r4 = _JC_INVOKE_VIRTUAL(env, soot_Body, getUnits$23294b6006422b2b, r1);
	r2 = _JC_INVOKE_VIRTUAL(env, soot_PatchingChain, iterator$3cc91493d50f531c, r4);

label0:
	_JC_LINE_NUMBER(47);				// 2
	z1 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0xfb0bd5e38c59ddcd), jboolean);
	if (z1 == 0)
		goto label1;
	_JC_LINE_NUMBER(48);				// 3
	r5 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x5874f79a1cf66ea), _jc_object *);
	r3 = _JC_CAST(env, &_jc_soot_Unit$type, r5);
	_JC_LINE_NUMBER(49);				// 4
	z1 = _JC_INSTANCEOF(env, r3, &_jc_soot_baf_InstanceCastInst$type);
	if (z1 == 0) {
		_JC_PERIODIC_CHECK(env);
		goto label0;
	}
	_JC_LINE_NUMBER(50);				// 5
	_JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0xfd50149979e1f350), void);
	_JC_LINE_NUMBER(51);				// 6
	z0 = 1;
	_JC_PERIODIC_CHECK(env);
	goto label0;

label1:
	_JC_LINE_NUMBER(55);				// 7
	return z0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_baf_toolkits_base_ExamplePeephole$methods[] = {
	&_jc_soot_baf_toolkits_base_ExamplePeephole$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_baf_toolkits_base_ExamplePeephole$method_info$apply$26c2d07493ac3443
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$interfaces[] = {
	&_jc_soot_baf_toolkits_base_Peephole$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_hash_bucket_67[] = {
	&_jc_soot_baf_toolkits_base_ExamplePeephole$method_info$apply$26c2d07493ac3443,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[67]=	_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_hash_bucket_67
};

// Interface "quick" lookup hash table
static const void *_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[67]=	&_jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_71[] = {
	&_jc_soot_baf_toolkits_base_ExamplePeephole$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_73[] = {
	&_jc_soot_baf_toolkits_base_Peephole$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[71]=	_jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_71,
	[73]=	_jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_73,
	[113]=	_jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_baf_toolkits_base_ExamplePeephole$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Iterator",	_JC_JLONG(0xbe56ff673eefd9d2) },
	{ "soot/Body",	_JC_JLONG(0x6131d54b9700ca5d) },
	{ "soot/PatchingChain",	_JC_JLONG(0x2869754f09a70a54) },
	{ "soot/Unit",	_JC_JLONG(0x771084b7dcf26138) },
	{ "soot/baf/InstanceCastInst",	_JC_JLONG(0xc3ac678fa21bb70d) },
	{ "soot/baf/toolkits/base/Peephole",	_JC_JLONG(0x6759975ef41a30c9) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_baf_toolkits_base_ExamplePeephole$vtype _jc_soot_baf_toolkits_base_ExamplePeephole$type = {
    .type= {
	.name=			"soot/baf/toolkits/base/ExamplePeephole",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$interfaces) / sizeof(*_jc_soot_baf_toolkits_base_ExamplePeephole$interfaces),
	.interfaces=		_jc_soot_baf_toolkits_base_ExamplePeephole$interfaces,
	.imethod_hash_table=	_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xdeba9086a8880c47),
		.source_file=		"ExamplePeephole.java",
		.instance_size=		sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$refs) + sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$methods) / sizeof(*_jc_soot_baf_toolkits_base_ExamplePeephole$methods),
		.methods=		_jc_soot_baf_toolkits_base_ExamplePeephole$methods,
		.instanceof_hash_table=	_jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$class_depends) / sizeof(*_jc_soot_baf_toolkits_base_ExamplePeephole$class_depends),
		.class_depends=		_jc_soot_baf_toolkits_base_ExamplePeephole$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_baf_toolkits_base_ExamplePeephole= {
	    .apply$26c2d07493ac3443=
		&_jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/baf/toolkits/base/ExamplePeephole.c <==
// public class soot.baf.toolkits.base.ExamplePeephole

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class be56ff673eefd9d2 java_util_Iterator
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 2869754f09a70a54 soot_PatchingChain
// @dep_class 771084b7dcf26138 soot_Unit
// @dep_class c3ac678fa21bb70d soot_baf_InstanceCastInst
// @dep_class deba9086a8880c47 soot_baf_toolkits_base_ExamplePeephole
// @dep_class 6759975ef41a30c9 soot_baf_toolkits_base_Peephole

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Iterator
// @dep_header soot_Body
// @dep_header soot_PatchingChain
// @dep_header soot_Unit
// @dep_header soot_baf_InstanceCastInst
// @dep_header soot_baf_toolkits_base_ExamplePeephole
// @dep_header soot_baf_toolkits_base_Peephole

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Iterator.h"
#include "soot/Body.h"
#include "soot/PatchingChain.h"
#include "soot/Unit.h"
#include "soot/baf/InstanceCastInst.h"
#include "soot/baf/toolkits/base/ExamplePeephole.h"
#include "soot/baf/toolkits/base/Peephole.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_baf_toolkits_base_ExamplePeephole$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_baf_toolkits_base_ExamplePeephole$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_baf_toolkits_base_ExamplePeephole$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_baf_toolkits_base_ExamplePeephole$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_baf_toolkits_base_ExamplePeephole$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_baf_toolkits_base_ExamplePeephole$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_baf_toolkits_base_ExamplePeephole$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_baf_toolkits_base_ExamplePeephole, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_baf_toolkits_base_ExamplePeephole$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_baf_toolkits_base_ExamplePeephole$object *this)
{
	struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(40);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public boolean apply(soot.Body)
//

static _jc_linenum _jc_soot_baf_toolkits_base_ExamplePeephole$linenum_table$apply$26c2d07493ac3443[];

static const unsigned char _jc_soot_baf_toolkits_base_ExamplePeephole$param_ptypes$apply$26c2d07493ac3443[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$param_types$apply$26c2d07493ac3443[] = {
	&_jc_soot_Body$type
};

_jc_method _jc_soot_baf_toolkits_base_ExamplePeephole$method_info$apply$26c2d07493ac3443 = {
	.name=			"apply",
	.signature=		"(Lsoot/Body;)Z",
	.class=			&_jc_soot_baf_toolkits_base_ExamplePeephole$type,
	.param_types=		&_jc_soot_baf_toolkits_base_ExamplePeephole$param_types$apply$26c2d07493ac3443,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_baf_toolkits_base_ExamplePeephole$param_ptypes$apply$26c2d07493ac3443,
	.signature_hash=	_JC_JLONG(0x26c2d07493ac3443),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtable, soot_baf_toolkits_base_ExamplePeephole.apply$26c2d07493ac3443) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	8,
	      .table=	_jc_soot_baf_toolkits_base_ExamplePeephole$linenum_table$apply$26c2d07493ac3443
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_baf_toolkits_base_ExamplePeephole, apply$26c2d07493ac3443);

jboolean _JC_JCNI_ATTR
_jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443(_jc_env *const env, _jc_soot_baf_toolkits_base_ExamplePeephole$object *this, _jc_soot_Body$object *param0)
{
	struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *r0;
	struct _jc_soot_Body$object *r1;
	struct _jc_object *r2;
	struct _jc_object *r3;
	struct _jc_soot_PatchingChain$object *r4;
	struct _jc_java_lang_Object$object *r5;
	jboolean z0;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(44);				// 0
	z0 = 0;
	_JC_LINE_NUMBER(46);				// 1
	r4 = _JC_INVOKE_VIRTUAL(env, soot_Body, getUnits$23294b6006422b2b, r1);
	r2 = _JC_INVOKE_VIRTUAL(env, soot_PatchingChain, iterator$3cc91493d50f531c, r4);

label0:
	_JC_LINE_NUMBER(47);				// 2
	z1 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0xfb0bd5e38c59ddcd), jboolean, (_jc_env *, struct _jc_object *));
	if (z1 == 0)
		goto label1;
	_JC_LINE_NUMBER(48);				// 3
	r5 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x5874f79a1cf66ea), _jc_object *, (_jc_env *, struct _jc_object *));
	r3 = _JC_CAST(env, &_jc_soot_Unit$type, r5);
	_JC_LINE_NUMBER(49);				// 4
	z1 = _JC_INSTANCEOF(env, r3, &_jc_soot_baf_InstanceCastInst$type);
	if (z1 == 0) {
		_JC_PERIODIC_CHECK(env);
		goto label0;
	}
	_JC_LINE_NUMBER(50);				// 5
	_JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0xfd50149979e1f350), void, (_jc_env *, struct _jc_object *));
	_JC_LINE_NUMBER(51);				// 6
	z0 = 1;
	_JC_PERIODIC_CHECK(env);
	goto label0;

label1:
	_JC_LINE_NUMBER(55);				// 7
	return z0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_baf_toolkits_base_ExamplePeephole$methods[] = {
	&_jc_soot_baf_toolkits_base_ExamplePeephole$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_baf_toolkits_base_ExamplePeephole$method_info$apply$26c2d07493ac3443
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$interfaces[] = {
	&_jc_soot_baf_toolkits_base_Peephole$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_hash_bucket_67[] = {
	&_jc_soot_baf_toolkits_base_ExamplePeephole$method_info$apply$26c2d07493ac3443,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[67]=	_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_hash_bucket_67
};

// Interface "quick" lookup hash table
static const void *_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[67]=	&_jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_71[] = {
	&_jc_soot_baf_toolkits_base_ExamplePeephole$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_73[] = {
	&_jc_soot_baf_toolkits_base_Peephole$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[71]=	_jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_71,
	[73]=	_jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_73,
	[101]=	_jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_baf_toolkits_base_ExamplePeephole$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Iterator",	_JC_JLONG(0xbe56ff673eefd9d2) },
	{ "soot/Body",	_JC_JLONG(0x6131d54b9700ca5d) },
	{ "soot/PatchingChain",	_JC_JLONG(0x2869754f09a70a54) },
	{ "soot/Unit",	_JC_JLONG(0x771084b7dcf26138) },
	{ "soot/baf/InstanceCastInst",	_JC_JLONG(0xc3ac678fa21bb70d) },
	{ "soot/baf/toolkits/base/Peephole",	_JC_JLONG(0x6759975ef41a30c9) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_baf_toolkits_base_ExamplePeephole$vtype _jc_soot_baf_toolkits_base_ExamplePeephole$type = {
    .type= {
	.name=			"soot/baf/toolkits/base/ExamplePeephole",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$interfaces) / sizeof(*_jc_soot_baf_toolkits_base_ExamplePeephole$interfaces),
	.interfaces=		_jc_soot_baf_toolkits_base_ExamplePeephole$interfaces,
	.imethod_hash_table=	_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_baf_toolkits_base_ExamplePeephole$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xdeba9086a8880c47),
		.source_file=		"ExamplePeephole.java",
		.instance_size=		sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$refs) + sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$methods) / sizeof(*_jc_soot_baf_toolkits_base_ExamplePeephole$methods),
		.methods=		_jc_soot_baf_toolkits_base_ExamplePeephole$methods,
		.instanceof_hash_table=	_jc_soot_baf_toolkits_base_ExamplePeephole$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_baf_toolkits_base_ExamplePeephole$class_depends) / sizeof(*_jc_soot_baf_toolkits_base_ExamplePeephole$class_depends),
		.class_depends=		_jc_soot_baf_toolkits_base_ExamplePeephole$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_baf_toolkits_base_ExamplePeephole= {
	    .apply$26c2d07493ac3443=
		&_jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443,
	},
    }
};
